#include	"unpipc.h"
#include	<stdarg.h>		/* for variable arg lists */
#include	<syslog.h>		/* for syslog() */

void Fclose(FILE *fp)
{
        if (fclose(fp) != 0)
                err_sys("fclose error");
}


/* include Close */
void Close(int fd)
{
	if (close(fd) == -1)
		err_sys("close error");
}
/* end Close */

void Pipe(int *fds)
{
	if (pipe(fds) < 0)
		err_sys("pipe error");
}

pid_t Fork(void)
{
	pid_t	pid;

	if ( (pid = fork()) == -1)
		err_sys("fork error");
	return(pid);
}

pid_t Waitpid(pid_t pid, int *iptr, int options)
{
	pid_t	retpid;

	if ( (retpid = waitpid(pid, iptr, options)) == -1)
		err_sys("waitpid error");
	return(retpid);
}


char * Fgets(char *ptr, int n, FILE *stream)
{
	char	*rptr;

	if ( (rptr = fgets(ptr, n, stream)) == NULL && ferror(stream))
		err_sys("fgets error");

	return (rptr);
}


ssize_t Read(int fd, void *ptr, size_t nbytes)
{
	ssize_t		n;

	if ( (n = read(fd, ptr, nbytes)) == -1)
		err_sys("read error");
	return(n);
}

void Write(int fd, void *ptr, size_t nbytes)
{
	if (write(fd, ptr, nbytes) != nbytes)
		err_sys("write error");
}


int Open(const char *pathname, int oflag, ...)
{
	int		fd;
	va_list	ap;
	mode_t	mode;

	if (oflag & O_CREAT) {
		va_start(ap, oflag);		/* init ap to final named argument */
		mode = va_arg(ap, va_mode_t);
		if ( (fd = open(pathname, oflag, mode)) == -1)
			err_sys("open error for %s", pathname);
		va_end(ap);
	} else {
		if ( (fd = open(pathname, oflag)) == -1)
			err_sys("open error for %s", pathname);
	}
	return(fd);
}


FILE * Popen(const char *command, const char *mode)
{
	FILE	*fp;

	if ( (fp = popen(command, mode)) == NULL)
		err_sys("popen error");
	return(fp);
}

void Fputs(const char *ptr, FILE *stream)
{
	if (fputs(ptr, stream) == EOF)
		err_sys("fputs error");
}

int Pclose(FILE *fp)
{
	int		n;

	if ( (n = pclose(fp)) == -1)
		err_sys("pclose error");
	return(n);
}

void Unlink(const char *pathname)
{
	if (unlink(pathname) == -1)
		err_sys("unlink error for %s", pathname);
}
